@@ -30,6 +30,11 @@ class DataSourceOutputML(BaseModel):
         "then this item stores one data item i.e Example",
     )
 
+    normalized: bool = Field(
+        False,
+        description="If the data field has been normalized or not",
+    )
+
     def get_name(self) -> str:
         """Get the name of the class"""
         return self.__class__.__name__.lower()
@@ -38,6 +43,11 @@ class DataSourceOutputML(BaseModel):
         """Datetime index for the data"""
         pass
 
+    def normalize(self):
+        """ Normalize the data """
+        pass
+
+
 
 def pad_nans(array, pad_width) -> np.ndarray:
     """Pad nans with nans"""
